@@ -10,13 +10,28 @@ end
 require 'rspec'
 require 'distribution'
 
+RSpec.configure do |config|
+  config.expect_with :rspec do |c|
+    c.syntax = [:should, :expect]
+  end
+
+  # Use color in STDOUT
+  config.color = true
+
+  # Use color not only in STDOUT but also in pagers and files
+  config.tty = true
+
+  # Use the specified formatter
+  config.formatter = :documentation # :progress, :html, :textmate
+end
+
 module ExampleWithGSL
-  def it_only_with_gsl(name,&block)
-    it(name) do
+  def it_only_with_gsl(name,opts={},&block)
+    it(name, opts) do
       if Distribution.has_gsl?
         instance_eval(&block)
       else
-        pending("Requires GSL")  
+        skip("Requires GSL")  
       end
     end
   end
@@ -26,7 +41,7 @@ module ExampleWithGSL
       if Distribution.has_java?
         instance_eval(&block)
       else
-        pending("Requires Java")  
+        skip("Requires Java")  
       end
     end
   end
